# foxinternalclient

Warning: Please add a custom user agent header to your requests.
This would help us fighting against DDoS attacks in future, while keeping your application's access to the API.
In future, this may be a mandatory requirement.

To reduce the system load, the API endpoints are rate limited.
The default limit is 30 requests per minute. Contact admin@orangefox.tech if you need a higher limit.

The requests may be logged for analytics and development purposes.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 5.2.2
- Package version: 5.2.2
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import foxinternalclient
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import foxinternalclient
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import foxinternalclient
from foxinternalclient.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.orangefox.download
# See configuration.py for a list of all supported configuration parameters.
configuration = foxinternalclient.Configuration(
    host = "https://api.orangefox.download"
)



# Enter a context with an instance of the API client
async with foxinternalclient.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = foxinternalclient.DeviceApi(api_client)
    device_id = '5f7a5c5b5c5b5c5b5c5b5c5b' # str |  (optional)
    id = '5f7a5c5b5c5b5c5b5c5b5c5b' # str | Filter by Device ID (deprecated) (optional)
    codename = 'codename_example' # str | Not recommended to use when you can (optional)

    try:
        # Get Device
        api_response = await api_instance.get_device(device_id=device_id, id=id, codename=codename)
        print("The response of DeviceApi->get_device:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DeviceApi->get_device: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.orangefox.download*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DeviceApi* | [**get_device**](docs/DeviceApi.md#get_device) | **GET** /devices/get | Get Device
*DeviceApi* | [**get_device_deprecated**](docs/DeviceApi.md#get_device_deprecated) | **GET** /devices/{device_id} | Get Device Short
*DeviceApi* | [**get_devices**](docs/DeviceApi.md#get_devices) | **GET** /devices/ | Get Devices
*DeviceApi* | [**get_oems**](docs/DeviceApi.md#get_oems) | **GET** /oems/ | Get Oems
*FoxFactoryApi* | [**cancel_task_factory_task_id_cancel_post**](docs/FoxFactoryApi.md#cancel_task_factory_task_id_cancel_post) | **POST** /factory/{task_id}/cancel | Cancel Task
*FoxFactoryApi* | [**delete_task_factory_task_id_delete**](docs/FoxFactoryApi.md#delete_task_factory_task_id_delete) | **DELETE** /factory/{task_id} | Delete Task
*FoxFactoryApi* | [**factory_status_factory_status_get**](docs/FoxFactoryApi.md#factory_status_factory_status_get) | **GET** /factory/status | Factory Status
*FoxFactoryApi* | [**get_task_factory_task_id_get**](docs/FoxFactoryApi.md#get_task_factory_task_id_get) | **GET** /factory/{task_id} | Get Task
*FoxFactoryApi* | [**list_tasks_factory_get**](docs/FoxFactoryApi.md#list_tasks_factory_get) | **GET** /factory/ | List Tasks
*FoxFactoryApi* | [**new_task_factory_post**](docs/FoxFactoryApi.md#new_task_factory_post) | **POST** /factory/ | New Task
*FoxFactoryApi* | [**update_task_factory_task_id_patch**](docs/FoxFactoryApi.md#update_task_factory_task_id_patch) | **PATCH** /factory/{task_id} | Update Task
*GitlabApi* | [**device_add_gitlab_repo_gitlab_device_device_id_gitlab_post**](docs/GitlabApi.md#device_add_gitlab_repo_gitlab_device_device_id_gitlab_post) | **POST** /gitlab/device/{device_id}/gitlab | Device Add Gitlab Repo
*InternalApi* | [**change_password_profile_change_password_post**](docs/InternalApi.md#change_password_profile_change_password_post) | **POST** /profile/change_password | Change Password
*InternalApi* | [**del_release_internal_releases_release_id_delete**](docs/InternalApi.md#del_release_internal_releases_release_id_delete) | **DELETE** /internal/releases/{release_id} | Del Release
*InternalApi* | [**delete_user_internal_users_user_id_delete**](docs/InternalApi.md#delete_user_internal_users_user_id_delete) | **DELETE** /internal/users/{user_id} | Delete User
*InternalApi* | [**edit_release_internal_releases_release_id_put**](docs/InternalApi.md#edit_release_internal_releases_release_id_put) | **PUT** /internal/releases/{release_id} | Edit Release
*InternalApi* | [**get_device_info_internal_devices_device_id_get**](docs/InternalApi.md#get_device_info_internal_devices_device_id_get) | **GET** /internal/devices/{device_id} | Get Device Info
*InternalApi* | [**get_logs_internal_logs_get**](docs/InternalApi.md#get_logs_internal_logs_get) | **GET** /internal/logs/ | Get Logs
*InternalApi* | [**get_release_info_internal_releases_release_id_get**](docs/InternalApi.md#get_release_info_internal_releases_release_id_get) | **GET** /internal/releases/{release_id} | Get Release Info
*InternalApi* | [**get_release_zip_internal_releases_release_id_dl_get**](docs/InternalApi.md#get_release_zip_internal_releases_release_id_dl_get) | **GET** /internal/releases/{release_id}/dl | Get Release Zip
*InternalApi* | [**get_user_by_id_internal_users_user_id_get**](docs/InternalApi.md#get_user_by_id_internal_users_user_id_get) | **GET** /internal/users/{user_id} | Get User By Id
*InternalApi* | [**list_users_internal_users_get**](docs/InternalApi.md#list_users_internal_users_get) | **GET** /internal/users/ | List Users
*InternalApi* | [**login_oauth_auth_login_post**](docs/InternalApi.md#login_oauth_auth_login_post) | **POST** /auth/login | Login Oauth
*InternalApi* | [**logout_auth_logout_post**](docs/InternalApi.md#logout_auth_logout_post) | **POST** /auth/logout | Logout
*InternalApi* | [**new_device_internal_devices_post**](docs/InternalApi.md#new_device_internal_devices_post) | **POST** /internal/devices/ | New Device
*InternalApi* | [**new_release_internal_releases_post**](docs/InternalApi.md#new_release_internal_releases_post) | **POST** /internal/releases/ | New Release
*InternalApi* | [**renew_auth_renew_post**](docs/InternalApi.md#renew_auth_renew_post) | **POST** /auth/renew | Renew
*InternalApi* | [**update_device_internal_devices_device_id_put**](docs/InternalApi.md#update_device_internal_devices_device_id_put) | **PUT** /internal/devices/{device_id} | Update Device
*InternalApi* | [**update_user_internal_users_user_id_put**](docs/InternalApi.md#update_user_internal_users_user_id_put) | **PUT** /internal/users/{user_id} | Update User
*ReleaseApi* | [**get_release**](docs/ReleaseApi.md#get_release) | **GET** /releases/get | Get Release
*ReleaseApi* | [**get_release_deprecated**](docs/ReleaseApi.md#get_release_deprecated) | **GET** /releases/{release_id} | Get Release Short
*ReleaseApi* | [**get_releases**](docs/ReleaseApi.md#get_releases) | **GET** /releases/ | Get Releases
*ReleaseApi* | [**get_updates_deprecated**](docs/ReleaseApi.md#get_updates_deprecated) | **GET** /updates/{last_known_id} | Get Updates
*StatsApi* | [**get_public_stats**](docs/StatsApi.md#get_public_stats) | **GET** /stats/ | Public Stats


## Documentation For Models

 - [BodyChangePasswordProfileChangePasswordPost](docs/BodyChangePasswordProfileChangePasswordPost.md)
 - [BuildStatusEnum](docs/BuildStatusEnum.md)
 - [BuildTaskResponse](docs/BuildTaskResponse.md)
 - [BuildTaskShortResponse](docs/BuildTaskShortResponse.md)
 - [DeviceInternalResponse](docs/DeviceInternalResponse.md)
 - [DeviceResponse](docs/DeviceResponse.md)
 - [DeviceStatsResponse](docs/DeviceStatsResponse.md)
 - [DeviceUpdateBody](docs/DeviceUpdateBody.md)
 - [FFStatusEnum](docs/FFStatusEnum.md)
 - [FFStatusResponse](docs/FFStatusResponse.md)
 - [GlobalStatsAggregationModel](docs/GlobalStatsAggregationModel.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [ListResponseReleaseResponse](docs/ListResponseReleaseResponse.md)
 - [ListResponseShortDeviceResponse](docs/ListResponseShortDeviceResponse.md)
 - [ListResponseShortReleaseResponse](docs/ListResponseShortReleaseResponse.md)
 - [ListResponseStr](docs/ListResponseStr.md)
 - [ListResponseUserShortResponse](docs/ListResponseUserShortResponse.md)
 - [LogListResponse](docs/LogListResponse.md)
 - [LogResponse](docs/LogResponse.md)
 - [MaintainerShortModel](docs/MaintainerShortModel.md)
 - [NewBuildTaskBody](docs/NewBuildTaskBody.md)
 - [NewDeviceBody](docs/NewDeviceBody.md)
 - [RecoveryImgResponse](docs/RecoveryImgResponse.md)
 - [ReleaseGroupsResponse](docs/ReleaseGroupsResponse.md)
 - [ReleaseInternalResponse](docs/ReleaseInternalResponse.md)
 - [ReleaseInternalResponsePropValue](docs/ReleaseInternalResponsePropValue.md)
 - [ReleaseResponse](docs/ReleaseResponse.md)
 - [ReleaseStatsResponse](docs/ReleaseStatsResponse.md)
 - [ReleaseType](docs/ReleaseType.md)
 - [ReleaseUpdateBody](docs/ReleaseUpdateBody.md)
 - [ReleasesSort](docs/ReleasesSort.md)
 - [ResponseGetReleases](docs/ResponseGetReleases.md)
 - [ShortDeviceResponse](docs/ShortDeviceResponse.md)
 - [ShortReleaseResponse](docs/ShortReleaseResponse.md)
 - [TaskUpdateBody](docs/TaskUpdateBody.md)
 - [TokenResponse](docs/TokenResponse.md)
 - [UserGitlab](docs/UserGitlab.md)
 - [UserInternalResponse](docs/UserInternalResponse.md)
 - [UserMail](docs/UserMail.md)
 - [UserShortResponse](docs/UserShortResponse.md)
 - [UserTelegram](docs/UserTelegram.md)
 - [UserUpdateBody](docs/UserUpdateBody.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearer_auth"></a>
### bearer_auth

- **Type**: Bearer authentication (JWT)

<a id="oauth2_password"></a>
### oauth2_password

- **Type**: OAuth
- **Flow**: password
- **Authorization URL**: 
- **Scopes**: N/A


## Author

admin@orangefox.tech


